Index: Thuban/Model/layer.py
===================================================================
RCS file: /thubanrepository/thuban/Thuban/Model/layer.py,v
retrieving revision 1.60
diff -u -r1.60 layer.py
--- Thuban/Model/layer.py	20 Sep 2004 08:13:00 -0000	1.60
+++ Thuban/Model/layer.py	24 Jan 2005 22:53:38 -0000
@@ -25,6 +25,7 @@
 
 import resource
 
+from color import Color
 
 shapetype_names = {SHAPETYPE_POINT: "Point",
                    SHAPETYPE_ARC: "Arc",
@@ -71,6 +72,9 @@
         self.projection = projection
         self.changed(LAYER_PROJECTION_CHANGED, self)
 
+    def Type(self):
+        return "Unknown"
+
 class Layer(BaseLayer):
 
     """Represent the information of one geodata file (currently a shapefile)
@@ -171,6 +175,9 @@
             bbox = self.projection.InverseBBox(bbox)
         return bbox
 
+    def Type(self):
+        return self.ShapeType();
+
     def ShapesBoundingBox(self, shapes):
         """Return a bounding box in lat/long coordinates for the given
         list of shape ids.
@@ -360,6 +367,11 @@
 
         self.bbox = -1
 
+        self.mask_color = None
+        self.use_mask = False
+
+        self.image_info = None
+
         if resource.has_gdal_support():
             #
             # temporarily open the file so that GDAL can test if it's valid.
@@ -369,6 +381,24 @@
             if dataset is None:
                 raise IOError()
 
+            #
+            # while we have the file, extract some basic information 
+            # that we can display later
+            #
+            self.image_info = {}
+
+            self.image_info["nBands"] = dataset.RasterCount
+            self.image_info["Size"] = (dataset.RasterXSize, dataset.RasterYSize)
+            self.image_info["Driver"] = dataset.GetDriver().ShortName
+
+            # store some information about the individual bands
+            # [min_value, max_value]
+            a = self.image_info["BandData"] = []
+
+            for i in range(1, dataset.RasterCount+1):
+                band = dataset.GetRasterBand(i)
+                a.append(band.ComputeRasterMinMax())
+
         self.UnsetModified()
 
     def BoundingBox(self):
@@ -423,8 +453,55 @@
 
         return bbox
 
+    def Type(self):
+        return "Image"
+
     def GetImageFilename(self):
         return self.filename
+
+    def HasMask(self):
+        """Return True if this layer has a mask."""
+        return self.mask_color is not None
+
+    def UseMask(self):
+        """Return True if the mask should be used when rendering the layer."""
+        return self.use_mask
+
+    def SetUseMask(self, use):
+        """Set whether to Use the mask set with SetMaskColor.
+
+        If the layer has no mask, this function does nothing.
+
+        If the state changes, a LAYER_CHANGED message is sent.
+        """
+        if self.HasMask() and use != self.use_mask: 
+            self.use_mask = use
+            self.changed(LAYER_CHANGED, self)
+
+    def MaskColor(self):
+        """Return the mask color"""
+        return self.mask_color
+
+    def SetMaskColor(self, mask, use = None):
+        """Set the color to use as a mask.
+
+        'mask' must be a Color object, or None. 
+        'use' must be a boolean value, or None. 
+        If 'mask' is not None, then 'use' determines if the mask is used.
+        If 'mask' is None, the mask will not be used, regardless of the
+        value of 'use'.
+
+        If any state changes, a LAYER_CHANGED message is sent.
+        """
+
+        if mask != self.MaskColor() or use != self.UseMask():
+            self.mask_color = mask
+            if use != None: self.use_mask = use
+            if mask is None: self.use_mask = False
+            self.changed(LAYER_CHANGED, self)
+
+    def ImageInfo(self):
+        return self.image_info
 
     def TreeInfo(self):
         items = []
